ConnectInstitution class

Constructors

ConnectInstitution({required String id, required ConnectAuthMethod authMethod})
const
ConnectInstitution.fromJson(String source)
factory
ConnectInstitution.fromMap(Map<String, dynamic> map)
factory

Properties

authMethod → ConnectAuthMethod
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? id, ConnectAuthMethod? authMethod}) → ConnectInstitution
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited