MonoCustomer class

Available extensions

Constructors

MonoCustomer({MonoExistingCustomerModel? existingCustomer, MonoNewCustomerModel? newCustomer})
const

Properties

existingCustomer → MonoExistingCustomerModel?
final
hashCode → int
The hash code for this object.
no setterinherited
newCustomer → MonoNewCustomerModel?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String

Available on MonoCustomer, provided by the MonoCustomerToJson extension

toMap() → Map<String, dynamic>

Available on MonoCustomer, provided by the MonoCustomerToJson extension

toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited