MonoNewCustomerModel class

Constructors

MonoNewCustomerModel({required String name, required String email, MonoNewCustomerIdentity? identity})
const
MonoNewCustomerModel.fromJson(String source)
factory
MonoNewCustomerModel.fromMap(Map<String, dynamic> map)
factory

Properties

email → String
final
hashCode → int
The hash code for this object.
no setterinherited
identity → MonoNewCustomerIdentity?
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? name, String? email, MonoNewCustomerIdentity? identity}) → MonoNewCustomerModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited