MonoEventData class

Constructors

MonoEventData({String? reference, String? pageName, String? prevAuthMethod, String? authMethod, String? mfaType, int? selectedAccountsCount, String? errorType, String? errorMessage, Map<String, dynamic>? institution, required int timestamp})
MonoEventData.fromJson(Map<String, dynamic> json)
factory

Properties

authMethod → String?
current auth method
final
errorMessage → String?
final
errorType → String?
final
hashCode → int
The hash code for this object.
no setterinherited
institution → Map<String, dynamic>?
final
institutionId → String?
no setter
institutionName → String?
no setter
mfaType → String?
type of MFA the current user/bank requires
final
pageName → String?
name of page the widget exited on
final
prevAuthMethod → String?
auth method before it was last changed
final
reference → String?
reference passed through the connect config
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedAccountsCount → int?
number of accounts selected by the user, emitted in ACCOUNT_SELECTED
final
timestamp → int
unix timestamp of the event as an Integer
final
toMap → Map<String, dynamic>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited