MonoWebView class

Inheritance

Constructors

MonoWebView({Key? key, required String apiKey, required MonoCustomer customer, Widget? error, dynamic onEvent(MonoEvent event, MonoEventData data)?, dynamic onSuccess(String code)?, dynamic onClosed(String? code)?, dynamic onLoad()?, String? paymentUrl, String? reference, ConnectInstitution? selectedInstitution, String reAuthCode = '', String scope = "auth"})
const

Properties

apiKey → String
Public API key gotten from your mono dashboard
final
customer → MonoCustomer
The customer objects expects the following keys based on the following conditions: New Customers: For new customers, the customer object expects the user’s name, email and identity Existing Customers: For existing customers, the customer object expects only the customer ID.
final
error → Widget?
An overlay widget to display over webview if page fails to load
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onClosed → dynamic Function(String? code)?
a function called when user clicks the close button on mono's page
final
onEvent → dynamic Function(MonoEvent event, MonoEventData data)?
final
onLoad → dynamic Function()?
a function called when the mono widget loads
final
onSuccess → dynamic Function(String code)?
a function called when transaction succeeds
final
paymentUrl → String?
final
reAuthCode → String
Public API key gotten from your mono dashboard
final
reference → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → String
set to true if you want to initiate a direct payment
final
selectedInstitution → ConnectInstitution?
Allows an optional selected institution to be passed.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → MonoWebViewState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited